@@ -13,17 +13,15 @@
 #    under the License.
 
 from django.conf import settings
-from troveclient.v1 import client
-
-from openstack_dashboard.api import base
-from oslo_log import log as logging
-
 from horizon.utils import functions as utils
 from horizon.utils.memoized import memoized  # noqa
-
-from keystoneauth1 import loading
 from keystoneauth1 import session
+from keystoneclient.auth import token_endpoint
 from novaclient import client as nova_client
+from openstack_auth import utils as auth_utils
+from openstack_dashboard.api import base
+from oslo_log import log as logging
+from troveclient.v1 import client
 
 # Supported compute versions
 NOVA_VERSIONS = base.APIVersionManager("compute", preferred_version=2)
@@ -39,17 +37,21 @@ LOG = logging.getLogger(__name__)
 def troveclient(request):
     insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
     cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
-    trove_url = base.url_for(request, 'database')
-    c = client.Client(request.user.username,
-                      request.user.token.id,
-                      project_id=request.user.project_id,
-                      auth_url=trove_url,
-                      insecure=insecure,
-                      cacert=cacert,
-                      http_log_debug=settings.DEBUG)
-    c.client.auth_token = request.user.token.id
-    c.client.management_url = trove_url
-    return c
+    endpoint_type = getattr(settings, 'OPENSTACK_ENDPOINT_TYPE', 'publicURL')
+    region = request.user.services_region
+
+    endpoint = base.url_for(request, 'database')
+    auth_url, _ = auth_utils.fix_auth_url_version_prefix(
+        settings.OPENSTACK_KEYSTONE_URL)
+    auth = token_endpoint.Token(auth_url, request.user.token.id)
+    verify = not insecure and (cacert or True)
+
+    t_client = client.Client(session=session.Session(auth=auth, verify=verify),
+                             service_type='database',
+                             endpoint_type=endpoint_type,
+                             region_name=region,
+                             endpoint_override=endpoint)
+    return t_client
 
 
 def cluster_list(request, marker=None):
@@ -144,20 +146,27 @@ def instance_delete(request, instance_id):
     return troveclient(request).instances.delete(instance_id)
 
 
-def instance_create(request, name, volume, flavor, databases=None,
+def instance_create(request, name, volume, flavor=None, databases=None,
                     users=None, restore_point=None, nics=None,
                     datastore=None, datastore_version=None,
                     replica_of=None, replica_count=None,
                     volume_type=None, configuration=None, locality=None,
-                    availability_zone=None):
+                    availability_zone=None, access=None):
     # TODO(dklyle): adding conditional to support trove without volume
     # support for now until API supports checking for volume support
-    if volume > 0:
+    if volume > 0 and not replica_of:
         volume_params = {'size': volume}
         if volume_type:
             volume_params['type'] = volume_type
     else:
         volume_params = None
+
+    if replica_of:
+        flavor = None
+        volume_params = None
+        datastore = None
+        datastore_version = None
+
     return troveclient(request).instances.create(
         name,
         flavor,
@@ -172,7 +181,8 @@ def instance_create(request, name, volume, flavor, databases=None,
         replica_count=replica_count,
         configuration=configuration,
         locality=locality,
-        availability_zone=availability_zone)
+        availability_zone=availability_zone,
+        access=access)
 
 
 def instance_resize_volume(request, instance_id, size):
@@ -192,9 +202,13 @@ def instance_restart(request, instance_id):
     return troveclient(request).instances.restart(instance_id)
 
 
+def instance_update(request, instance_id, **kwargs):
+    return troveclient(request).instances.update(instance_id, **kwargs)
+
+
 def instance_detach_replica(request, instance_id):
-    return troveclient(request).instances.edit(instance_id,
-                                               detach_replica_source=True)
+    return troveclient(request).instances.update(instance_id,
+                                                 detach_replica_source=True)
 
 
 def promote_to_replica_source(request, instance_id):
@@ -246,25 +260,48 @@ def backup_delete(request, backup_id):
 
 
 def backup_create(request, name, instance_id, description=None,
-                  parent_id=None):
+                  parent_id=None, swift_container=None):
     return troveclient(request).backups.create(name, instance_id,
-                                               description, parent_id)
+                                               description=description,
+                                               parent_id=parent_id,
+                                               swift_container=swift_container)
+
+
+def backup_strategy_create(request, instance_id=None, swift_container=None):
+    return troveclient(request).backup_strategies.create(
+        instance_id=instance_id, swift_container=swift_container)
+
+
+def backup_strategy_list(request, instance_id=None, project_id=None):
+    return troveclient(request).backup_strategies.list(instance_id=instance_id,
+                                                       project_id=project_id)
+
+
+def backup_strategy_delete(request, instance_id=None, project_id=None):
+    return troveclient(request).backup_strategies.delete(
+        instance_id=instance_id, project_id=project_id)
 
 
 def nova_client_client(request):
     insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
     cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
-    identity_url = base.url_for(request, 'identity')
-    loader = loading.get_plugin_loader('token')
-    auth = loader.load_from_options(auth_url=identity_url,
-                                    token=request.user.token.id,
-                                    tenant_id=request.user.project_id)
-    sess = session.Session(auth=auth)
-    nova = nova_client.Client(NOVA_VERSION,
-                              session=sess,
-                              insecure=insecure,
-                              cacert=cacert,
-                              http_log_debug=settings.DEBUG)
+    endpoint_type = getattr(settings, 'OPENSTACK_ENDPOINT_TYPE', 'publicURL')
+    region = request.user.services_region
+
+    endpoint = base.url_for(request, 'compute')
+    auth_url, _ = auth_utils.fix_auth_url_version_prefix(
+        settings.OPENSTACK_KEYSTONE_URL)
+    auth = token_endpoint.Token(auth_url, request.user.token.id)
+    verify = not insecure and (cacert or True)
+
+    nova = nova_client.Client(
+        NOVA_VERSION,
+        session=session.Session(auth=auth, verify=verify),
+        endpoint_type=endpoint_type,
+        service_type='compute',
+        region_name=region,
+        endpoint_override=endpoint)
+
     return nova
 
 
@@ -357,19 +394,23 @@ def log_list(request, instance_id):
 
 
 def log_enable(request, instance_id, log_name):
-    return troveclient(request).instances.log_enable(instance_id, log_name)
+    return troveclient(request).instances.log_action(instance_id, log_name,
+                                                     enable=True)
 
 
 def log_disable(request, instance_id, log_name):
-    return troveclient(request).instances.log_disable(instance_id, log_name)
+    return troveclient(request).instances.log_action(instance_id, log_name,
+                                                     disable=True)
 
 
 def log_publish(request, instance_id, log_name):
-    return troveclient(request).instances.log_publish(instance_id, log_name)
+    return troveclient(request).instances.log_action(instance_id, log_name,
+                                                     publish=True)
 
 
 def log_discard(request, instance_id, log_name):
-    return troveclient(request).instances.log_discard(instance_id, log_name)
+    return troveclient(request).instances.log_action(instance_id, log_name,
+                                                     discard=True)
 
 
 def log_tail(request, instance_id, log_name, publish, lines, swift=None):
@@ -420,3 +461,7 @@ def configuration_update(request, group_id, values):
 
 def configuration_default(request, instance_id):
     return troveclient(request).instances.configuration(instance_id)
+
+
+def stop_database(request, instance_id):
+    return troveclient(request).mgmt_instances.stop(instance_id)
