@@ -14,13 +14,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import logging
-
-from django.core import urlresolvers
 from django import shortcuts
 from django.template.defaultfilters import title  # noqa
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django import urls
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 
 from horizon import messages
 from horizon import tables
@@ -28,6 +26,7 @@ from horizon.templatetags import sizeformat
 from horizon.utils import filters
 from horizon.utils import functions
 from horizon.utils import memoized
+from oslo_log import log as logging
 
 from trove_dashboard import api
 from trove_dashboard.content.database_clusters import cluster_manager
@@ -46,7 +45,7 @@ class DeleteCluster(tables.BatchAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Delete Cluster",
             u"Delete Clusters",
             count
@@ -54,7 +53,7 @@ class DeleteCluster(tables.BatchAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Scheduled deletion of Cluster",
             u"Scheduled deletion of Clusters",
             count
@@ -110,7 +109,7 @@ class ResetPassword(tables.LinkAction):
 
     def get_link_url(self, datum):
         cluster_id = self.table.get_object_id(datum)
-        return urlresolvers.reverse(self.url, args=[cluster_id])
+        return urls.reverse(self.url, args=[cluster_id])
 
 
 class UpdateRow(tables.Row):
@@ -208,6 +207,12 @@ def get_host(instance):
     return _("Not Assigned")
 
 
+def get_instance_volume_size(instance):
+    if hasattr(instance, "volume"):
+        return sizeformat.diskgbformat(instance.volume.get("size"))
+    return _("Not available")
+
+
 class InstancesTable(tables.DataTable):
     name = tables.Column("name",
                          verbose_name=_("Name"))
@@ -218,6 +223,9 @@ class InstancesTable(tables.DataTable):
     size = tables.Column(get_instance_size,
                          verbose_name=_("Size"),
                          attrs={'data-type': 'size'})
+    volume_size = tables.Column(get_instance_volume_size,
+                                verbose_name=_("Volume Size"),
+                                attrs={'data-type': 'size'})
     status = tables.Column("status",
                            filters=(title, filters.replace_underscores),
                            verbose_name=_("Status"))
@@ -236,7 +244,7 @@ class ClusterShrinkAction(tables.BatchAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Shrink Cluster",
             u"Shrink Cluster",
             count
@@ -244,7 +252,7 @@ class ClusterShrinkAction(tables.BatchAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Scheduled Shrinking of Cluster",
             u"Scheduled Shrinking of Cluster",
             count
@@ -270,10 +278,10 @@ class ClusterShrinkAction(tables.BatchAction):
         except Exception as ex:
             LOG.error('Action %(action)s failed with %(ex)s for %(data)s' %
                       {'action': self._get_action_name(past=True).lower(),
-                       'ex': ex.message,
+                       'ex': ex,
                        'data': display_str})
             msg = _('Unable to remove instances from cluster: %s')
-            messages.error(request, msg % ex.message)
+            messages.error(request, msg % ex)
 
         return shortcuts.redirect(self.get_success_url(request))
 
@@ -299,7 +307,7 @@ class ClusterGrowAddInstance(tables.LinkAction):
     classes = ("ajax-modal",)
 
     def get_link_url(self):
-        return urlresolvers.reverse(
+        return urls.reverse(
             self.url, args=[self.table.kwargs['cluster_id']])
 
 
@@ -308,7 +316,7 @@ class ClusterGrowRemoveInstance(tables.BatchAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Remove Instance",
             u"Remove Instances",
             count
@@ -316,7 +324,7 @@ class ClusterGrowRemoveInstance(tables.BatchAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Removed Instance",
             u"Removed Instances",
             count
@@ -405,14 +413,14 @@ class ClusterGrowAction(tables.Action):
             messages.success(request, msg)
         except Exception as ex:
             LOG.error('Action grow cluster failed with %(ex)s for %(data)s' %
-                      {'ex': ex.message,
+                      {'ex': ex,
                        'data': display_str})
             msg = _('Unable to grow cluster: %s')
-            messages.error(request, msg % ex.message)
+            messages.error(request, msg % ex)
         finally:
             cluster_manager.delete(cluster_id)
 
-        return shortcuts.redirect(urlresolvers.reverse(
+        return shortcuts.redirect(urls.reverse(
             "horizon:project:database_clusters:index"))
 
 
