@@ -40,7 +40,7 @@ DETAILS_URL = reverse('horizon:project:databases:detail', args=['id'])
 
 class DatabaseTests(test.TestCase):
     @test.create_mocks(
-        {api.trove: ('instance_list', 'flavor_list')})
+        {api.trove: ('instance_get', 'instance_list', 'flavor_list')})
     def test_index(self):
         # Mock database instances
         databases = common.Paginated(self.databases.list())
@@ -51,6 +51,9 @@ class DatabaseTests(test.TestCase):
         res = self.client.get(INDEX_URL)
         self.mock_instance_list.assert_called_once_with(
             test.IsHttpRequest(), marker=None)
+        replica_id = databases[-1].replicas[0]['id']
+        self.mock_instance_get.assert_called_once_with(test.IsHttpRequest(),
+                                                       replica_id)
         self.mock_flavor_list.assert_called_once_with(test.IsHttpRequest())
         self.assertTemplateUsed(res, 'project/databases/index.html')
         # Check the Host column displaying ip or hostname
@@ -58,7 +61,7 @@ class DatabaseTests(test.TestCase):
         self.assertContains(res, 'trove.instance-2.com')
 
     @test.create_mocks(
-        {api.trove: ('instance_list', 'flavor_list')})
+        {api.trove: ('instance_get', 'instance_list', 'flavor_list')})
     def test_index_flavor_exception(self):
         # Mock database instances
         databases = common.Paginated(self.databases.list())
@@ -69,12 +72,15 @@ class DatabaseTests(test.TestCase):
         res = self.client.get(INDEX_URL)
         self.mock_instance_list.assert_called_once_with(
             test.IsHttpRequest(), marker=None)
+        replica_id = databases[-1].replicas[0]['id']
+        self.mock_instance_get.assert_called_once_with(test.IsHttpRequest(),
+                                                       replica_id)
         self.mock_flavor_list.assert_called_once_with(test.IsHttpRequest())
         self.assertTemplateUsed(res, 'project/databases/index.html')
         self.assertMessageCount(res, error=1)
 
     @test.create_mocks(
-        {api.trove: ('instance_list',)})
+        {api.trove: ('instance_get', 'instance_list',)})
     def test_index_list_exception(self):
         # Mock database instances
         self.mock_instance_list.side_effect = self.exceptions.trove
@@ -86,7 +92,7 @@ class DatabaseTests(test.TestCase):
         self.assertMessageCount(res, error=1)
 
     @test.create_mocks(
-        {api.trove: ('instance_list', 'flavor_list')})
+        {api.trove: ('instance_get', 'instance_list', 'flavor_list')})
     def test_index_pagination(self):
         # Mock database instances
         databases = self.databases.list()
@@ -99,13 +105,16 @@ class DatabaseTests(test.TestCase):
         res = self.client.get(INDEX_URL)
         self.mock_instance_list.assert_called_once_with(
             test.IsHttpRequest(), marker=None)
+        replica_id = databases[-1].replicas[0]['id']
+        self.mock_instance_get.assert_called_once_with(test.IsHttpRequest(),
+                                                       replica_id)
         self.mock_flavor_list.assert_called_once_with(test.IsHttpRequest())
         self.assertTemplateUsed(res, 'project/databases/index.html')
         self.assertContains(
             res, 'marker=' + last_record.id)
 
     @test.create_mocks(
-        {api.trove: ('instance_list', 'flavor_list')})
+        {api.trove: ('instance_get', 'instance_list', 'flavor_list')})
     def test_index_flavor_list_exception(self):
         # Mocking instances.
         databases = common.Paginated(self.databases.list())
@@ -116,6 +125,9 @@ class DatabaseTests(test.TestCase):
         res = self.client.get(INDEX_URL)
         self.mock_instance_list.assert_called_once_with(
             test.IsHttpRequest(), marker=None)
+        replica_id = databases[-1].replicas[0]['id']
+        self.mock_instance_get.assert_called_once_with(test.IsHttpRequest(),
+                                                       replica_id)
         self.mock_flavor_list.assert_called_once_with(test.IsHttpRequest())
         self.assertTemplateUsed(res, 'project/databases/index.html')
         self.assertMessageCount(res, error=1)
@@ -125,7 +137,7 @@ class DatabaseTests(test.TestCase):
                     'datastore_list', 'datastore_version_list', 'flavor_list',
                     'instance_list'),
         dash_api.cinder: ('volume_type_list',),
-        dash_api.neutron: ('network_list',),
+        dash_api.neutron: ('network_list_for_tenant',),
         dash_api.nova: ('availability_zone_list',),
         policy: ('check',),
     })
@@ -143,15 +155,14 @@ class DatabaseTests(test.TestCase):
 
         self.mock_volume_type_list.return_value = []
 
-        self.mock_network_list.side_effect = [self.networks.list()[:1],
-                                              self.networks.list()[1:]]
+        self.mock_network_list_for_tenant.return_value = self.networks.list()
 
         self.mock_availability_zone_list.return_value = (
             self.availability_zones.list())
 
         res = self.client.get(LAUNCH_URL)
         self.assert_mock_multiple_calls_with_same_arguments(
-            self.mock_check, 4, mock.call((), test.IsHttpRequest()))
+            self.mock_check, 5, mock.call((), test.IsHttpRequest()))
         self.assert_mock_multiple_calls_with_same_arguments(
             self.mock_datastore_flavors, 20,
             mock.call(test.IsHttpRequest(),
@@ -167,11 +178,9 @@ class DatabaseTests(test.TestCase):
             mock.call(test.IsHttpRequest(), test.IsA(str)))
         self.mock_volume_type_list.assert_called_once_with(
             test.IsHttpRequest())
-        self.mock_network_list.assert_has_calls([
-            mock.call(test.IsHttpRequest(),
-                      tenant_id=self.tenant.id,
-                      shared=False),
-            mock.call(test.IsHttpRequest(), shared=True)])
+        self.mock_network_list_for_tenant.assert_called_once_with(
+            test.IsHttpRequest(), self.tenant.id,
+            include_pre_auto_allocate=True)
         self.mock_availability_zone_list.assert_called_once_with(
             test.IsHttpRequest())
         self.assertTemplateUsed(res, 'project/databases/launch.html')
@@ -213,7 +222,7 @@ class DatabaseTests(test.TestCase):
                     'datastore_list', 'datastore_version_list', 'flavor_list',
                     'instance_create', 'instance_list'),
         dash_api.cinder: ('volume_type_list',),
-        dash_api.neutron: ('network_list',),
+        dash_api.neutron: ('network_list_for_tenant',),
         dash_api.nova: ('availability_zone_list',),
         policy: ('check',),
     })
@@ -230,8 +239,7 @@ class DatabaseTests(test.TestCase):
 
         self.mock_volume_type_list.return_value = []
 
-        self.mock_network_list.side_effect = [self.networks.list()[:1],
-                                              self.networks.list()[1:]]
+        self.mock_network_list_for_tenant.return_value = self.networks.list()
 
         nics = [{"net-id": self.networks.first().id}]
 
@@ -257,7 +265,7 @@ class DatabaseTests(test.TestCase):
 
         res = self.client.post(LAUNCH_URL, post)
         self.assert_mock_multiple_calls_with_same_arguments(
-            self.mock_check, 4, mock.call((), test.IsHttpRequest()))
+            self.mock_check, 5, mock.call((), test.IsHttpRequest()))
         self.assert_mock_multiple_calls_with_same_arguments(
             self.mock_datastore_flavors, 20,
             mock.call(test.IsHttpRequest(),
@@ -271,11 +279,9 @@ class DatabaseTests(test.TestCase):
             mock.call(test.IsHttpRequest(), test.IsA(str)))
         self.mock_volume_type_list.assert_called_once_with(
             test.IsHttpRequest())
-        self.mock_network_list.assert_has_calls([
-            mock.call(test.IsHttpRequest(),
-                      tenant_id=self.tenant.id,
-                      shared=False),
-            mock.call(test.IsHttpRequest(), shared=True)])
+        self.mock_network_list_for_tenant.assert_called_once_with(
+            test.IsHttpRequest(), self.tenant.id,
+            include_pre_auto_allocate=True)
         self.mock_availability_zone_list.assert_called_once_with(
             test.IsHttpRequest())
         self.mock_instance_create.assert_called_once_with(
@@ -294,7 +300,8 @@ class DatabaseTests(test.TestCase):
             replica_count=None,
             volume_type=None,
             locality=None,
-            availability_zone=test.IsA(str))
+            availability_zone=test.IsA(str),
+            access=None)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
     @test.create_mocks({
@@ -302,7 +309,7 @@ class DatabaseTests(test.TestCase):
                     'datastore_list', 'datastore_version_list', 'flavor_list',
                     'instance_create', 'instance_list'),
         dash_api.cinder: ('volume_type_list',),
-        dash_api.neutron: ('network_list',),
+        dash_api.neutron: ('network_list_for_tenant',),
         dash_api.nova: ('availability_zone_list',),
         policy: ('check',),
     })
@@ -320,8 +327,7 @@ class DatabaseTests(test.TestCase):
 
         self.mock_volume_type_list.return_value = []
 
-        self.mock_network_list.side_effect = [self.networks.list()[:1],
-                                              self.networks.list()[1:]]
+        self.mock_network_list_for_tenant.return_value = self.networks.list()
 
         nics = [{"net-id": self.networks.first().id}]
 
@@ -347,7 +353,7 @@ class DatabaseTests(test.TestCase):
 
         res = self.client.post(LAUNCH_URL, post)
         self.assert_mock_multiple_calls_with_same_arguments(
-            self.mock_check, 4, mock.call((), test.IsHttpRequest()))
+            self.mock_check, 5, mock.call((), test.IsHttpRequest()))
         self.assert_mock_multiple_calls_with_same_arguments(
             self.mock_datastore_flavors, 20,
             mock.call(test.IsHttpRequest(),
@@ -361,11 +367,9 @@ class DatabaseTests(test.TestCase):
             mock.call(test.IsHttpRequest(), test.IsA(str)))
         self.mock_volume_type_list.assert_called_once_with(
             test.IsHttpRequest())
-        self.mock_network_list.assert_has_calls([
-            mock.call(test.IsHttpRequest(),
-                      tenant_id=self.tenant.id,
-                      shared=False),
-            mock.call(test.IsHttpRequest(), shared=True)])
+        self.mock_network_list_for_tenant.assert_called_once_with(
+            test.IsHttpRequest(), self.tenant.id,
+            include_pre_auto_allocate=True)
         self.mock_availability_zone_list.assert_called_once_with(
             test.IsHttpRequest())
         self.mock_instance_create.assert_called_once_with(
@@ -384,7 +388,8 @@ class DatabaseTests(test.TestCase):
             replica_count=None,
             volume_type=None,
             locality=None,
-            availability_zone=test.IsA(str))
+            availability_zone=test.IsA(str),
+            access=None)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
     @test.create_mocks({
@@ -1034,7 +1039,7 @@ class DatabaseTests(test.TestCase):
                     'datastore_list', 'datastore_version_list', 'flavor_list',
                     'instance_create', 'instance_get', 'instance_list_all'),
         dash_api.cinder: ('volume_type_list',),
-        dash_api.neutron: ('network_list',),
+        dash_api.neutron: ('network_list_for_tenant',),
         dash_api.nova: ('availability_zone_list',),
         policy: ('check',),
     })
@@ -1049,8 +1054,7 @@ class DatabaseTests(test.TestCase):
 
         self.mock_volume_type_list.return_value = []
 
-        self.mock_network_list.side_effect = [self.networks.list()[:1],
-                                              self.networks.list()[1:]]
+        self.mock_network_list_for_tenant.return_value = self.networks.list()
 
         nics = [{"net-id": self.networks.first().id}]
 
@@ -1081,7 +1085,7 @@ class DatabaseTests(test.TestCase):
 
         res = self.client.post(LAUNCH_URL, post)
         self.assert_mock_multiple_calls_with_same_arguments(
-            self.mock_check, 4, mock.call((), test.IsHttpRequest()))
+            self.mock_check, 5, mock.call((), test.IsHttpRequest()))
         self.assert_mock_multiple_calls_with_same_arguments(
             self.mock_datastore_flavors, 20,
             mock.call(test.IsHttpRequest(),
@@ -1096,11 +1100,9 @@ class DatabaseTests(test.TestCase):
             mock.call(test.IsHttpRequest(), test.IsA(str)))
         self.mock_volume_type_list.assert_called_once_with(
             test.IsHttpRequest())
-        self.mock_network_list.assert_has_calls([
-            mock.call(test.IsHttpRequest(),
-                      tenant_id=self.tenant.id,
-                      shared=False),
-            mock.call(test.IsHttpRequest(), shared=True)])
+        self.mock_network_list_for_tenant.assert_called_once_with(
+            test.IsHttpRequest(), self.tenant.id,
+            include_pre_auto_allocate=True)
         self.mock_availability_zone_list.assert_called_once_with(
             test.IsHttpRequest())
         self.mock_instance_get.assert_called_once_with(
@@ -1121,7 +1123,8 @@ class DatabaseTests(test.TestCase):
             replica_count=2,
             volume_type=None,
             locality=None,
-            availability_zone=test.IsA(str))
+            availability_zone=test.IsA(str),
+            access=None)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
     @test.create_mocks({
@@ -1244,7 +1247,7 @@ class DatabaseTests(test.TestCase):
             mock.call(request)]
         self.assertEqual(expected_calls,
                          self.mock_instance_list.call_args_list)
-        self.assertTrue(len(choices) == len(self.databases.list()) + 1)
+        self.assertEqual(len(choices), len(self.databases.list()) + 1)
 
     def _build_datastore_display_text(self, datastore, datastore_version):
         return datastore + ' - ' + datastore_version
