@@ -14,7 +14,7 @@
 
 from django.conf import settings
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -23,17 +23,57 @@ from horizon import workflows
 from openstack_dashboard import api as dash_api
 from openstack_dashboard.dashboards.project.instances \
     import utils as instance_utils
-from openstack_dashboard.dashboards.project.instances.workflows \
-    import create_instance as dash_create_instance
 from oslo_log import log as logging
 
-
 from trove_dashboard import api
 from trove_dashboard.utils import common as common_utils
 
 LOG = logging.getLogger(__name__)
 
 
+# NOTE(hiwkby): SetNetworkAction is migrated from horizon for compatibiity
+class SetNetworkAction(workflows.Action):
+    network = forms.MultipleChoiceField(
+        label=_("Networks"),
+        widget=forms.ThemableCheckboxSelectMultiple(),
+        error_messages={'required': _("At least one network must be "
+                                      "specified.")},
+        help_text=_("Launch instance with these networks"))
+
+    def __init__(self, request, *args, **kwargs):
+        super().__init__(request, *args, **kwargs)
+        self.use_required_attribute = False
+
+        network_list = self.fields["network"].choices
+        if len(network_list) == 1:
+            self.fields['network'].initial = [network_list[0][0]]
+
+    class Meta(object):
+        name = _("Networking")
+        permissions = ('openstack.services.network',)
+        help_text = _("Select networks for your instance.")
+
+    def populate_network_choices(self, request, context):
+        return instance_utils.network_field_data(request, for_launch=True)
+
+
+# NOTE(hiwkby): SetNetwork is migrated from horizon for compatibiity
+class SetNetwork(workflows.Step):
+    action_class = SetNetworkAction
+    template_name = "project/databases/_update_networks.html"
+    contributes = ("network_id",)
+
+    def contribute(self, data, context):
+        if data:
+            networks = self.workflow.request.POST.getlist("network")
+            # If no networks are explicitly specified, network list
+            # contains an empty string, so remove it.
+            networks = [n for n in networks if n != '']
+            if networks:
+                context['network_id'] = networks
+        return context
+
+
 def parse_datastore_and_version_text(datastore_and_version):
     if datastore_and_version:
         datastore, datastore_version = datastore_and_version.split('-', 1)
@@ -283,6 +323,34 @@ class SetInstanceDetails(workflows.Step):
                    "locality", "availability_zone")
 
 
+class AddAccessAction(workflows.Action):
+    """Initialize the database access. This tab will honor
+        the settings which should be a list of permissions required:
+
+        * TROVE_ADD_USER_PERMS = []
+        * TROVE_ADD_DATABASE_PERMS = []
+        """
+    is_public = forms.BooleanField(label=_("Is Public"),
+                                   required=False)
+    allowed_cidrs = forms.MultiIPField(label=_("Allowed CIDRs"),
+                                       required=False,
+                                       version=forms.IPv4 | forms.IPv6,
+                                       mask=True,
+                                       widget=forms.TextInput(),
+                                       help_text=_("Comma-separated CIDRs "
+                                                   "to connect through."))
+
+    class Meta(object):
+        name = _("Database Access")
+        permissions = TROVE_ADD_PERMS
+        help_text_template = "project/databases/_launch_access_help.html"
+
+
+class DatabaseAccess(workflows.Step):
+    action_class = AddAccessAction
+    contributes = ["is_public", "allowed_cidrs"]
+
+
 class AddDatabasesAction(workflows.Action):
     """Initialize the database with users/databases. This tab will honor
     the settings which should be a list of permissions required:
@@ -368,12 +436,7 @@ class AdvancedAction(workflows.Action):
         required=False,
         min_value=1,
         initial=1,
-        help_text=_('Specify the number of replicas to be created'),
-        widget=forms.TextInput(attrs={
-            'class': 'switched',
-            'data-switch-on': 'initial_state',
-            'data-initial_state-master': _('Replica Count')
-        }))
+        help_text=_('Specify the number of replicas to be created'))
 
     def __init__(self, request, *args, **kwargs):
         if args[0]:
@@ -416,7 +479,7 @@ class AdvancedAction(workflows.Action):
             for b in backups:
                 if self.backup_id and b.id != self.backup_id:
                     continue
-                if b.status == 'COMPLETED':
+                if b.status in ['COMPLETED', 'RESTORED']:
                     choices.append((b.id, b.name))
         except Exception:
             choices = []
@@ -440,7 +503,7 @@ class AdvancedAction(workflows.Action):
         try:
             instances = self._get_instances()
             choices = sorted([(i.id, i.name) for i in
-                             instances if i.status == 'ACTIVE'],
+                             instances if i.status == 'HEALTHY'],
                              key=lambda i: i[1])
         except Exception:
             choices = []
@@ -494,6 +557,7 @@ class AdvancedAction(workflows.Action):
                 raise forms.ValidationError(
                     _("A master instance must be selected!"))
 
+            cleaned_data['flavor'] = None
             cleaned_data['backup'] = None
         else:
             cleaned_data['master'] = None
@@ -516,7 +580,8 @@ class LaunchInstance(workflows.Workflow):
     failure_message = _('Unable to launch %(count)s named "%(name)s".')
     success_url = "horizon:project:databases:index"
     default_steps = (SetInstanceDetails,
-                     dash_create_instance.SetNetwork,
+                     SetNetwork,
+                     DatabaseAccess,
                      InitializeDatabase,
                      Advanced)
 
@@ -581,6 +646,16 @@ class LaunchInstance(workflows.Workflow):
             locality = context['locality']
         return locality
 
+    def _get_access(self, context):
+        if not context['allowed_cidrs'] and not context['is_public']:
+            return None
+        access = {}
+        if context['allowed_cidrs'] != '':
+            access['allowed_cidrs'] = context['allowed_cidrs'].split(',')
+        if context['is_public']:
+            access['is_public'] = True
+        return access
+
     def handle(self, request, context):
         try:
             datastore, datastore_version = parse_datastore_and_version_text(
@@ -601,6 +676,7 @@ class LaunchInstance(workflows.Workflow):
                      context.get('master'), context['replica_count'],
                      context.get('config'), self._get_locality(context),
                      avail_zone)
+
             api.trove.instance_create(request,
                                       context['name'],
                                       context['volume'],
@@ -617,7 +693,8 @@ class LaunchInstance(workflows.Workflow):
                                           context),
                                       configuration=context.get('config'),
                                       locality=self._get_locality(context),
-                                      availability_zone=avail_zone)
+                                      availability_zone=avail_zone,
+                                      access=self._get_access(context))
             return True
         except Exception:
             exceptions.handle(request)
